==================
PyAMS_skin package
==================

.. contents::


What is PyAMS?
==============

PyAMS (Pyramid Application Management Suite) is a small suite of packages written for applications
and content management with the Pyramid framework.

**PyAMS** is actually mainly used to manage web sites through content management applications (CMS,
see PyAMS_content package), but many features are generic and can be used inside any kind of web
application.

All PyAMS documentation is available on `ReadTheDocs <https://pyams.readthedocs.io>`_; source code
is available on `Gitlab <https://gitlab.com/pyams>`_ and pushed to `Github
<https://github.com/py-ams>`_.


What is PyAMS_skin?
===================

PyAMS_skin is an extension package to PyAMS which defines a small set of interfaces and content
providers which can be used in any kind of application.

It also provides a small set of custom form widgets and buttons, and overrides default templates
of many widgets provided by PyAMS_form package.
